import java.io.*;
import java.util.*;

public class Overflow {

    final long INF = (long)1e18;

    final class SegmentTree {
        long[] value;
        int[] forPos;
        int size;

        SegmentTree(int size) {
            this.size = size;
            value = new long[4 * size + 10];
            forPos = new int[size];
            Arrays.fill(value, INF);
            build(0, 0, size - 1);
        }

        void build(int i, int l, int r) {
            if (l == r) {
                forPos[l] = i;
                return;
            }
            int m = (l + r) / 2;
            build(2 * i + 1, l, m);
            build(2 * i + 2, m + 1, r);
        }

        void clear() {
            Arrays.fill(value, INF);
        }

        void put(int pos, long val) {
            int i = forPos[pos];
            if (val == INF || val < value[i])
                value[i] = val;
            if (i == 0)
                return;
            while (i != 0) {
                i = (i - 1) / 2;
                value[i] = value[2 * i + 1];
                if (value[2 * i + 2] < value[i])
                    value[i] = value[2 * i + 2];
            }
        }

        int getFirstLower(int i, int tl, int tr, long upperBound) {
            if (value[i] > upperBound)
                return -1;
            while (tl != tr) {
                int m = (tl + tr) / 2;
                if (value[2 * i + 1] <= upperBound) {
                    i = 2 * i + 1;
                    tr = m;
                } else {
                    i = 2 * i + 2;
                    tl = m + 1;
                }
            }
            return tl;
        }

        int getFirstLower(long upperBound) {
            return getFirstLower(0, 0, size - 1, upperBound);
        }
    }

    class NaiveTree {
        long[] value;

        NaiveTree(int size) {
            value = new long[size];
            Arrays.fill(value, INF);
        }

        void put(int pos, long val) {
            if (val == INF || val < value[pos])
                value[pos] = val;
        }

        int getFirstLower(long upperBound) {
            for (int i = 0; i < value.length; i++)
                if (value[i] <= upperBound)
                    return i;
            return -1;
        }
    }

    void checkTree() {
        TreeChecker treeChecker = new TreeChecker();
        treeChecker.check(10, 10, 100, 100);
    }


    class TreeChecker {
        Random random = new Random();

        void check(int maxSize, int maxValue, int tests, int queriesPerTest) {
            for (int i = 0; i < tests; i++) {
                int curSize = random.nextInt(maxSize) + 1;
                SegmentTree fastTree = new SegmentTree(curSize);
                NaiveTree slowTree = new NaiveTree(curSize);
                for (int q = 0; q < queriesPerTest; q++) {
                    int pos = random.nextInt(curSize);
                    long value = random.nextInt(maxValue + 1);
                    if (value == maxValue)
                        value = INF;
                    fastTree.put(pos, value);
                    slowTree.put(pos, value);
                    for (int bound = -1; bound <= maxValue; bound++)
                        if (fastTree.getFirstLower(bound) != slowTree.getFirstLower(bound))
                            throw new AssertionError("The segment tree is incorrect");
                }
            }
        }
    }

    class Compressor {
        List<Integer> values;

        Compressor(List<Integer> values) {
            List<Integer> temp = new ArrayList<>(values);
            Collections.sort(temp);
            this.values = new ArrayList<>();
            for (int i = 0; i < temp.size(); i++)
                if (i == 0 || !temp.get(i).equals(temp.get(i - 1)))
                    this.values.add(temp.get(i));
        }

        int size() {
            return values.size();
        }

        int getCompressed(int key) {
            int pos = Collections.binarySearch(values, key);
            if (pos >= 0)
                return pos;
            return -(pos + 1);
        }

        int getDecompressed(int key) {
            return values.get(key);
        }
    }

    class Segment implements Comparable<Segment> {
        int left;
        int right;
        long height;

        Segment(int left, int right, long height) {
            this.left = left;
            this.right = right;
            this.height = height;
        }

        @Override
        public int compareTo(Segment other) {
            return Integer.compare(left, other.left);
        }

        @Override
        public String toString() {
            return "Segment: {" + left + ", " + right + ", " + height + "}";
        }
    }

    List<Integer>[] toAddPos;
    List<Long>[] toAddVal;
    SegmentTree tree;
    Compressor compressor;

    boolean can(List<Segment> segments, long maxHeight, int k, int zero, int maxX) {
        int n = segments.size();
        tree.clear();
        for (int i = 0; i < maxX; i++) {
            toAddPos[i].clear();
            toAddVal[i].clear();
        }
        int nonZero = 0;
        Set<Integer> toExtend = new HashSet<>();
        for (; nonZero < n && segments.get(nonZero).left <= zero; nonZero++) {
            if (segments.get(nonZero).height <= maxHeight) {
                if (segments.get(nonZero).right >= k)
                    return true;
                tree.put(segments.get(nonZero).right, segments.get(nonZero).height);
                toExtend.add(segments.get(nonZero).right);
            }
        }
        int lastDeleted = 0;
        for (int i = nonZero; i < n; i++) {
            int left = segments.get(i).left;
            while (lastDeleted < left) {
                for (int j = 0; j < toAddPos[lastDeleted].size(); j++)
                    if (toAddPos[lastDeleted].get(j) >= left)
                        tree.put(toAddPos[lastDeleted].get(j),
                                toAddVal[lastDeleted].get(j));
                tree.put(lastDeleted, INF);
                lastDeleted++;
            }
            long height = segments.get(i).height;
            int prev = tree.getFirstLower(maxHeight - height);
            int right = segments.get(i).right;
            boolean canGoFromLeftMinusOne =  left > 0
                    && compressor.getDecompressed(left) - compressor.getDecompressed(left - 1) == 1;
            if (canGoFromLeftMinusOne && height <= maxHeight && toExtend.contains(left - 1))
                prev = left;
            if (prev == -1 || prev > right)
                continue;
            if (right >= k)
                return true;
            toExtend.add(right);
            toAddPos[prev].add(right);
            toAddVal[prev].add(height);
        }
        return false;
    }

    long solveFast(List<Integer> left, List<Integer> right, List<Long> height, int k) {
        List<Integer> allX = new ArrayList<>();
        allX.add(0);
        allX.add(k);
        int low = 0;
        int high = 0;
        for (int i = 0; i < left.size(); i++) {
            if (right.get(i) < 0)
                continue;
            allX.add(right.get(i));
            allX.add(left.get(i));
            high = Math.max(high, (int)(2 * height.get(i) + 1));
        }
        if (high == 0)
            return -1;
        compressor = new Compressor(allX);
        int maxX = compressor.size();
        toAddPos = new List[maxX];
        toAddVal = new List[maxX];
        tree = new SegmentTree(maxX);
        for (int i = 0; i < maxX; i++) {
            toAddPos[i] = new ArrayList<>();
            toAddVal[i] = new ArrayList<>();
        }
        k = compressor.getCompressed(k);
        int zero = compressor.getCompressed(0);
        List<Segment> segments = new ArrayList<>();
        for (int i = 0; i < left.size(); i++) {
            if (right.get(i) <= 0)
                continue;
            segments.add(new Segment(
                    compressor.getCompressed(left.get(i)),
                    compressor.getCompressed(right.get(i)),
                    height.get(i)));
        }
        Collections.sort(segments);
        long initialHigh = high;
        while (high - low > 1) {
            int mid = (low + high) / 2;
            if (can(segments, mid, k, zero, maxX))
                high = mid;
            else
                low = mid;
        }
        if (high == initialHigh)
            high = -1;
        return high;
    }

    long solveSlow(List<Integer> left, List<Integer> right, List<Long> height, int k) {
        int n = left.size();
        long res = INF;
        for (int mask = 1; mask < (1 << n); mask++) {
            int[] cnt = new int[k + 1];
            long[] sum = new long[k + 1];
            long cur = 0;
            for (int i = 0; i < n; i++)
                if ((mask & (1 << i)) != 0) {
                    for (int x = left.get(i); x <= right.get(i) - 1; x++)
                        if (x >= 0 && x < k) {
                            cnt[x]++;
                            sum[x] += height.get(i);
                        }
                    if (right.get(i) >= 0 && right.get(i) <= k)
                        sum[right.get(i)] += height.get(i);
                }
            for (int i = 0; i < k; i++) {
                cur = Math.max(cur, sum[i]);
                if (cnt[i] == 0)
                    cur = INF;
            }
            cur = Math.max(cur, sum[k]);
            res = Math.min(res, cur);
        }
        if (res == INF)
            res = -1;
        return res;
    }

    void checkSolution(int tests, int maxCnt, int maxK) {
        Random random = new Random();
        int nonTrivial = 0;
        for (int t = 0; t < tests; t++) {
            int size = random.nextInt(maxCnt) + 1;
            List<Integer> left = new ArrayList<>();
            List<Integer> right = new ArrayList<>();
            List<Long> height = new ArrayList<>();
            int k = random.nextInt(maxK - 1) + 2;
            for (int i = 0; i < size; i++) {
                int l = random.nextInt(2 + maxK) - 2;
                int r = random.nextInt(2 + maxK) - 2;
                if (l == r)
                    r++;
                else if (l > r) {
                    int temp = l;
                    l = r;
                    r = temp;
                }
                left.add(l);
                right.add(r);
                height.add((long)random.nextInt(10) + 1);
            }
            long fast = solveFast(left, right, height, k);
            long slow = solveSlow(left, right, height, k);
            if (fast != slow) {
                System.err.println(left + " " + right + " " + height + " " + k);
                System.err.println(slow + " " + fast);
                throw new AssertionError("");
            }
            if (slow > 0)
                nonTrivial++;
        }
        System.err.println(nonTrivial);
    }

    void testLarge(int size, int len) {
        Random random = new Random();
        int k = size * len;
        List<Integer> left = new ArrayList<>();
        List<Integer> right = new ArrayList<>();
        List<Long> height = new ArrayList<>();
        for (int i = 0; i < size; i++) {
            left.add(len * i);
            right.add(len * i + len);
            height.add((long)random.nextInt(1000 * 1000 * 1000) + 1);
        }
        long time = System.currentTimeMillis();
        System.err.println(solveFast(left, right, height, k));
        System.err.println("time: " + (System.currentTimeMillis() - time) / 1e3);
    }

    public void solve() throws Exception {
        //checkTree();
        //checkSolution(100000, 10, 10);
        //testLarge(100000, 1000);
        int n = in.nextInt();
        int k = in.nextInt() - 1;
        List<Integer> left = new ArrayList<>();
        List<Integer> right = new ArrayList<>();
        List<Long> height = new ArrayList<>();
        for (int i = 0; i < n; i++) {
            left.add(in.nextInt() - 1);
            right.add(in.nextInt() - 1);
            height.add(in.nextLong());
        }
        out.println(solveFast(left, right, height, k));
    }


    FastScanner in = new FastScanner(System.in);
    PrintWriter out = new PrintWriter(System.out);

    public static void main(String[] args) throws Exception {
        Overflow m = new Overflow();
        m.solve();
        m.out.close();
    }

    public class FastScanner {
        private StringTokenizer tokenizer;
        private BufferedReader reader;

        public FastScanner(InputStream inputStream) {
            reader = new BufferedReader(new InputStreamReader(inputStream));
        }

        public String nextLine() {
            try {
                return reader.readLine();
            } catch (IOException e) {

            }
            return null;
        }

        public String next() {
            while (tokenizer == null || !tokenizer.hasMoreTokens()) {
                String line = null;
                try {
                    line = reader.readLine();
                } catch (IOException e) {
                    // ignore
                }
                if (line == null)
                    return null;
                tokenizer = new StringTokenizer(line);
            }
            return tokenizer.nextToken();
        }

        public int nextInt() {
            return Integer.parseInt(next());
        }

        public long nextLong() {
            return Long.parseLong(next());
        }

        public double nextDouble() {
            return Double.parseDouble(next());
        }

        public void close() {
            try {
                reader.close();
            } catch (IOException e) {
                // ignore
            }
        }
    }
}
